@@ -2,19 +2,19 @@
 *
 *  =========== DOCUMENTATION ===========
 *
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
 *
 *  Definition:
 *  ===========
 *
 *       SUBROUTINE ZERRED( PATH, NUNIT )
-* 
+*
 *       .. Scalar Arguments ..
 *       CHARACTER*3        PATH
 *       INTEGER            NUNIT
 *       ..
-*  
+*
 *
 *> \par Purpose:
 *  =============
@@ -36,6 +36,8 @@
 *>       ZGEJSV   compute SVD of an M-by-N matrix A where M >= N
 *>       ZGESVDX  compute SVD of an M-by-N matrix A(by bisection
 *>                and inverse iteration)
+*>       ZGESVDQ  compute SVD of an M-by-N matrix A(with a 
+*>                QR-Preconditioned )
 *> \endverbatim
 *
 *  Arguments:
@@ -56,22 +58,19 @@
 *  Authors:
 *  ========
 *
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
-*
-*> \date November 2015
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
 *
 *> \ingroup complex16_eig
 *
 *  =====================================================================
       SUBROUTINE ZERRED( PATH, NUNIT )
 *
-*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER*3        PATH
@@ -100,8 +99,8 @@
      $                   VT( NMAX, NMAX ), W( 10*NMAX ), X( NMAX )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CHKXER, ZGEES, ZGEESX, ZGEEV, ZGEEVX, ZGESVJ, 
-     $                   ZGESDD, ZGESVD
+      EXTERNAL           CHKXER, ZGEES, ZGEESX, ZGEEV, ZGEEVX, ZGESVJ,
+     $                   ZGESDD, ZGESVD, ZGESVDX, ZGESVQ
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAMEN, ZSLECT
@@ -441,51 +440,51 @@
 *
          SRNAMT = 'ZGESVDX'
          INFOT = 1
-         CALL ZGESVDX( 'X', 'N', 'A', 0, 0, A, 1, ZERO, ZERO, 
+         CALL ZGESVDX( 'X', 'N', 'A', 0, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 2
-         CALL ZGESVDX( 'N', 'X', 'A', 0, 0, A, 1, ZERO, ZERO, 
+         CALL ZGESVDX( 'N', 'X', 'A', 0, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 3
-         CALL ZGESVDX( 'N', 'N', 'X', 0, 0, A, 1, ZERO, ZERO, 
+         CALL ZGESVDX( 'N', 'N', 'X', 0, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 4
-         CALL ZGESVDX( 'N', 'N', 'A', -1, 0, A, 1, ZERO, ZERO, 
+         CALL ZGESVDX( 'N', 'N', 'A', -1, 0, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 5
-         CALL ZGESVDX( 'N', 'N', 'A', 0, -1, A, 1, ZERO, ZERO, 
+         CALL ZGESVDX( 'N', 'N', 'A', 0, -1, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 7
-         CALL ZGESVDX( 'N', 'N', 'A', 2, 1, A, 1, ZERO, ZERO, 
+         CALL ZGESVDX( 'N', 'N', 'A', 2, 1, A, 1, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 8
-         CALL ZGESVDX( 'N', 'N', 'V', 2, 1, A, 2, -ONE, ZERO, 
+         CALL ZGESVDX( 'N', 'N', 'V', 2, 1, A, 2, -ONE, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 9
-         CALL ZGESVDX( 'N', 'N', 'V', 2, 1, A, 2, ONE, ZERO, 
+         CALL ZGESVDX( 'N', 'N', 'V', 2, 1, A, 2, ONE, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 10
-         CALL ZGESVDX( 'N', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+         CALL ZGESVDX( 'N', 'N', 'I', 2, 2, A, 2, ZERO, ZERO,
      $                 0, 1, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 11
-         CALL ZGESVDX( 'V', 'N', 'I', 2, 2, A, 2, ZERO, ZERO, 
+         CALL ZGESVDX( 'V', 'N', 'I', 2, 2, A, 2, ZERO, ZERO,
      $                 1, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 15
-         CALL ZGESVDX( 'V', 'N', 'A', 2, 2, A, 2, ZERO, ZERO, 
+         CALL ZGESVDX( 'V', 'N', 'A', 2, 2, A, 2, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          INFOT = 17
-         CALL ZGESVDX( 'N', 'V', 'A', 2, 2, A, 2, ZERO, ZERO, 
+         CALL ZGESVDX( 'N', 'V', 'A', 2, 2, A, 2, ZERO, ZERO,
      $                 0, 0, NS, S, U, 1, VT, 1, W, 1, RW, IW, INFO )
          CALL CHKXER( 'ZGESVDX', INFOT, NOUT, LERR, OK )
          NT = 12
@@ -495,6 +494,61 @@
          ELSE
             WRITE( NOUT, FMT = 9998 )
          END IF
+*
+*        Test ZGESVDQ
+*
+         SRNAMT = 'ZGESVDQ'
+         INFOT = 1
+         CALL ZGESVDQ( 'X', 'P', 'T', 'A', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 2
+         CALL ZGESVDQ( 'A', 'X', 'T', 'A', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 3
+         CALL ZGESVDQ( 'A', 'P', 'X', 'A', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 4
+         CALL ZGESVDQ( 'A', 'P', 'T', 'X', 'A', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 5
+         CALL ZGESVDQ( 'A', 'P', 'T', 'A', 'X', 0, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 6
+         CALL ZGESVDQ( 'A', 'P', 'T', 'A', 'A', -1, 0, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 7
+         CALL ZGESVDQ( 'A', 'P', 'T', 'A', 'A', 0, 1, A, 1, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 9
+         CALL ZGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 0, S, U,
+     $                 0, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 12
+         CALL ZGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 1, S, U,
+     $                 -1, VT, 0, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 14
+         CALL ZGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 1, S, U,
+     $                 1, VT, -1, NS, IW, 1, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         INFOT = 17
+         CALL ZGESVDQ( 'A', 'P', 'T', 'A', 'A', 1, 1, A, 1, S, U,
+     $                 1, VT, 1, NS, IW, -5, W, 1, RW, 1, INFO )
+         CALL CHKXER( 'ZGESVDQ', INFOT, NOUT, LERR, OK )
+         NT = 11
+         IF( OK ) THEN
+            WRITE( NOUT, FMT = 9999 )SRNAMT( 1:LEN_TRIM( SRNAMT ) ),
+     $           NT
+         ELSE
+            WRITE( NOUT, FMT = 9998 )
+         END IF
       END IF
 *
 *     Print a summary line.
